package MyRule::Oppai::JA;

use strict;

sub name { 'おっぱい' }

1;
